@@ -1,7 +1,7 @@
 ##----------------------------------------------------------------------------
 ## Stripe API - ~/lib/Net/API/Stripe/Connect/Person.pm
-## Version 0.1.1
-## Copyright(c) 2019 DEGUEST Pte. Ltd.
+## Version 0.2
+## Copyright(c) 2020 DEGUEST Pte. Ltd.
 ## Author: Jacques Deguest <jack@deguest.jp>
 ## Created 2019/11/02
 ## Modified 2020/03/29
@@ -18,7 +18,7 @@ BEGIN
 	use DateTime;
 	use DateTime::Format::Strptime;
 	use TryCatch;
-	our( $VERSION ) = '0.1.1';
+	our( $VERSION ) = '0.2';
 };
 
 sub id { return( shift->_set_get_scalar( 'id', @_ ) ); }
@@ -121,7 +121,7 @@ Net::API::Stripe::Connect::Person - A Stripe Person Object
 
 =head1 VERSION
 
-    0.1.1
+    0.2
 
 =head1 DESCRIPTION
 
