@@ -16,8 +16,8 @@ BEGIN
 {
     use strict;
     use parent qw( Net::API::Stripe::Generic );
-	use B;
-	use B::Deparse;
+	# use B;
+	# use B::Deparse;
     our( $VERSION ) = '0.2';
 };
 
